<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-safehtml?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// S
	'safehtml_description' => 'Schutz der Foren gegen cross-site scripting Attacken',
	'safehtml_slogan' => 'Schutz der Foren gegen cross-site scripting Attacken'
);

?>
